@@ -38,8 +38,8 @@ __author__ = "James Mills"
 __author_email__ = "%s, prologic at shortcircuit dot net dot au" % __author__
 __maintainer__ = __author__
 __maintainer_email__ = __author_email__
-__url__ = "http://trac.shortcircuit.net.au/circuits/"
-__download_url__ = "http://trac.softcircuit.com.au/circuits/downloads/%s-%s.tar.gz" % (__name__, __version__)
+__url__ = "http://code.google.com/p/circuits/"
+__download_url__ = "http://circuits.googlecode.com/files/%s-%s.tar.gz" % (__name__, __version__)
 __copyright__ = "Copyright (C) 2004-2009 by %s" % __author__
 __license__ = "MIT"
 __platforms__ = "POSIX"
