@@ -1,13 +1,11 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# vim: set sw=3 sts=3 ts=3
 
 import pygame
 from pygame import K_q
 from pygame import DOUBLEBUF, HWSURFACE
 
 from circuits import Component, Debugger
-from circuits.drivers import PyGameDriver
+from circuits.drivers._pygame import PyGameDriver
 
 class Test(Component):
 
@@ -24,5 +22,4 @@ class Test(Component):
     def quit(self):
         raise SystemExit, 0
 
-if __name__ == "__main__":
-    Test().run()
+Test().run()
