@@ -20,12 +20,14 @@ This example makes use of:
     * lib.sockets.TCPClient
 """
 
+import os
 import optparse
+from socket import gethostname
 
-from circuits.lib.io import stdin
+from circuits.io import stdin
 from circuits import handler, Component
 from circuits import __version__ as systemVersion
-from circuits.lib.sockets import TCPClient, Connect, Write
+from circuits.net.sockets import TCPClient, UNIXClient, Connect, Write
 
 USAGE = "%prog [options] host [port]"
 VERSION = "%prog v" + systemVersion
@@ -63,17 +65,37 @@ class Telnet(Component):
 
     channel = "telnet"
 
-    def __init__(self, host, port):
+    def __init__(self, *args):
         super(Telnet, self).__init__()
 
-        self += TCPClient(channel=self.channel)
-        self.push(Connect(host, port), "connect")
+        if len(args) == 1:
+            if os.path.exists(args[0]):
+                self += UNIXClient(channel=self.channel)
+                host = gethostname()
+                dest = port = args[0]
+            else:
+                raise OSError("Path %s not found" % args[0])
+        else:
+            self += TCPClient(channel=self.channel)
+            host, port = args
+            port = int(port)
+            dest = host, port
 
-    def connected(self, host, port):
+        print "Trying %s ..." % host
+        self.push(Connect(*dest), "connect")
+
+    def connected(self, host, port=None):
         print "Connected to %s" % host
 
-    def error(self, e):
-        print "ERROR: %r" % e
+    def error(self, *args):
+        if len(args) == 3:
+            type, value, traceback = args
+        else:
+            value = args[0]
+            type = type(value)
+            traceback = None
+
+        print "ERROR: %s" % value
 
     def read(self, data):
         print data.strip()
@@ -89,15 +111,7 @@ class Telnet(Component):
 def main():
     opts, args = parse_options()
 
-    host = args[0]
-    if len(args) > 1:
-        port = int(args[1])
-    else:
-        port = 23
-
-    print "Trying %s..." % host
-
-    (Telnet(host, port) + stdin).run()
+    (Telnet(*args) + stdin).run()
 
 ###
 ### Entry Point
